BufferViewMut

Struct BufferViewMut 

pub struct BufferViewMut<'a, U: Copy> { /* private fields */ }
A mutable, type-reinterpreted view into a DeviceBuffer.

Like BufferView but allows mutable operations (e.g., passing to a kernel that writes through this reinterpreted pointer).

Implementations

Source

impl<U: Copy> BufferViewMut<'_, U>

pub fn len(&self) -> usize

Returns the number of U elements in this view.

pub fn is_empty(&self) -> bool

Returns true if the view contains zero elements.

pub fn byte_size(&self) -> usize

Returns the total byte size of this view.

pub fn as_device_ptr(&self) -> CUdeviceptr

Returns the raw CUdeviceptr for this view.