enable_peer_access

Function enable_peer_access 

pub fn enable_peer_access(device: &Device, peer: &Device) -> CudaResult<()>
Enables peer access from device’s primary context to peer’s primary context.

After calling this function, kernels and copy operations running on device can directly read from and write to memory allocated on peer.

Errors