pub enum PressureLevel {
Nominal,
Warning,
Critical,
}Expand description
The classified memory-pressure state.
Ordered by severity so levels can be compared directly
(Nominal < Warning < Critical).
Variants
Nominal
Used fraction below the warning threshold.
Warning
Used fraction at/above the warning threshold but below critical.
Critical
Used fraction at/above the critical threshold.
Implementations
Sourceimpl PressureLevel
impl PressureLevel
Sourcepub fn is_critical(self) -> bool
pub fn is_critical(self) -> bool
Returns true if this is the Critical level.
Sourcepub fn is_elevated(self) -> bool
pub fn is_elevated(self) -> bool
Returns true if this level is at least Warning.