pub struct PressureSample {
pub level: PressureLevel,
pub used_fraction: f64,
pub previous: PressureLevel,
}Expand description
The outcome of classifying one memory sample.
Fields
level: PressureLevelThe classified level.
used_fraction: f64The used fraction (0.0–1.0) that produced the classification.
previous: PressureLevelThe previous level before this sample (for transition detection).
Implementations
Sourceimpl PressureSample
impl PressureSample
Sourcepub fn escalated(&self) -> bool
pub fn escalated(&self) -> bool
Returns true if this sample represents a transition into a strictly
more severe level than the previous sample.
Sourcepub fn de_escalated(&self) -> bool
pub fn de_escalated(&self) -> bool
Returns true if this sample represents a transition into a strictly
less severe level than the previous sample.