VirtualAddressRange

Struct VirtualAddressRange 

pub struct VirtualAddressRange { /* private fields */ }
A reserved range of virtual addresses in the GPU address space.

This represents a contiguous block of virtual addresses that has been reserved but not necessarily backed by physical memory. Physical memory is associated with the range via VirtualMemoryManager::map.

Note

On systems without CUDA virtual memory support, the base address is set to 0 and operations on the range will return CudaError::NotSupported.

Implementations

Source

impl VirtualAddressRange

pub fn base(&self) -> u64

Returns the base virtual address of the range.

pub fn size(&self) -> usize

Returns the size of the range in bytes.

pub fn alignment(&self) -> usize

Returns the alignment of the range in bytes.

pub fn contains(&self, addr: u64) -> bool

Returns whether the range contains the given virtual address.

pub fn end(&self) -> u64

Returns the end address (exclusive) of the range.