pub fn check_alignment(ptr: CUdeviceptr) -> AlignmentInfoExpand description
Inspects a device pointer and reports its alignment characteristics.
For a null (zero) pointer the natural alignment is reported as usize::MAX
because zero is trivially aligned to every power of two.