pub fn enable_peer_access(device: &Device, peer: &Device) -> CudaResult<()>Expand description
Enables peer access from device’s primary context to peer’s primary context.
After calling this function, kernels and copy operations running on device
can directly read from and write to memory allocated on peer.
Errors
CudaError::PeerAccessAlreadyEnabledif peer access is already enabled.CudaError::PeerAccessUnsupportedif the hardware topology does not support direct peer access between these devices.