pub struct VirtualAddressRange { /* private fields */ }Expand description
A reserved range of virtual addresses in the GPU address space.
This represents a contiguous block of virtual addresses that has been
reserved but not necessarily backed by physical memory. Physical memory
is associated with the range via VirtualMemoryManager::map.
Note
On systems without CUDA virtual memory support, the base address
is set to 0 and operations on the range will return
CudaError::NotSupported.
Implementations